/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'fr', {
	button: 'Insérer un extrait de code',
	codeContents: 'Code',
	emptySnippetError: 'Un extrait de code ne peut pas être vide.',
	language: 'Langue',
	title: 'Extrait de code',
	pathName: 'extrait de code'
} );
