CKEDITOR.plugins.setLang('youtube', 'vi', {
	button : 'Embed Youtube Video',
	title : 'Nhúng Video Youtube',
	txtEmbed : 'Dãn mã nhúng Embed vào đây',
	txtUrl : 'Dãn đường dẫn video Youtube',
	txtWidth : 'Rộng',
	txtHeight : 'Cao',
	chkRelated : 'Hiển thị các video được đề xuất khi video kết thúc',
	txtStartAt : 'Bắt đầu (ss hoặc mm:ss hoặc hh:mm:ss)',
	chkPrivacy : 'Kích hoạt chế độ bảo mật nâng cao',
	chkOlderCode : 'Sử dụng mã nhúng cũ',
	chkAutoplay: 'Tự động chạy video',
	chkControls: 'Hiển thị các điều khiển trình phát',
	noCode : 'Bạn phải nhập mã nhúng hoặc URL',
	invalidEmbed : 'Mã nhúng bạn đã nhập không đúng',
	invalidUrl : 'URL bạn đã nhập không đúng',
	or : 'hoặc',
	noWidth : 'Bạn phải chiều rộng',
	invalidWidth : 'Chiều rộng hợp lệ',
	noHeight : 'Bạn phải chiều cao',
	invalidHeight : 'Chiều cao hợp lệ',
	invalidTime : 'Thời gian bắt đầu không đúng',
	txtResponsive : 'Responsive video'
});
