/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'sq', {
	button: 'Shto kod copëze',
	codeContents: 'Përmbajtja e kodit',
	emptySnippetError: 'Copëza e kodit nuk mund të jetë e zbrazët.',
	language: 'Gjuha',
	title: 'Copëza e kodit',
	pathName: 'copëza e kodit'
} );
