/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'ko', {
	button: '코드 스니펫 삽입',
	codeContents: '코드 본문',
	emptySnippetError: '코드 스니펫은 빈칸일 수 없습니다.',
	language: '언어',
	title: '코드 스니펫',
	pathName: '코드 스니펫'
} );
