/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'sr-latn', {
	button: 'Nalepi delić koda',
	codeContents: 'Sadržaj koda',
	emptySnippetError: 'Delić koda ne može biti prazan',
	language: 'Jezik',
	title: 'Delić koda',
	pathName: 'Delić koda'
} );
