/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'ro', {
	button: 'Adaugă segment de cod',
	codeContents: 'Conținutul codului',
	emptySnippetError: 'Un segment de cod nu poate fi gol.',
	language: 'Limba',
	title: 'Segment de cod',
	pathName: 'segment de cod'
} );
