/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'pl', {
	button: 'Wstaw fragment kodu',
	codeContents: 'Treść kodu',
	emptySnippetError: 'Kod nie może być pusty.',
	language: 'Język',
	title: 'Fragment kodu',
	pathName: 'fragment kodu'
} );
